==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/Documents.java <==
package com.example.model;

/**
 * Model for Documents
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.329Z")
@io.swagger.annotations.ApiModel(value = "Documents", description = "Model for Documents")
@javax.xml.bind.annotation.XmlRootElement(name = "Documents")
public class Documents implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private com.example.model.AsfBreakdown asfBreakdown = null;
	private java.time.OffsetDateTime createdAt = null;
	private java.lang.String documentId = null;
	private com.example.model.Extracted extracted = null;
	private com.example.model.File facePhoto = null;
	private com.example.model.File frontDocument = null;
	private java.lang.String identityDocumentType = null;
	private java.lang.Boolean ocr = null;
	private com.example.model.File originalFrontDocument = null;
	private java.time.OffsetDateTime updatedAt = null;
	
	/**
	 * Model for AsfBreakdown
	 */
	public Documents asfBreakdown(com.example.model.AsfBreakdown asfBreakdown) {
		setAsfBreakdown(asfBreakdown);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "Model for AsfBreakdown")
	@com.fasterxml.jackson.annotation.JsonProperty("asf_breakdown")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public com.example.model.AsfBreakdown getAsfBreakdown() {
		return this.asfBreakdown;
	}
	public void setAsfBreakdown(com.example.model.AsfBreakdown asfBreakdown) {
		this.asfBreakdown = asfBreakdown;
	}
	
	/**
	 */
	public Documents createdAt(java.time.OffsetDateTime createdAt) {
		setCreatedAt(createdAt);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("created_at")
	public java.time.OffsetDateTime getCreatedAt() {
		return this.createdAt;
	}
	public void setCreatedAt(java.time.OffsetDateTime createdAt) {
		this.createdAt = createdAt;
	}
	
	/**
	 */
	public Documents documentId(java.lang.String documentId) {
		setDocumentId(documentId);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("document_id")
	public java.lang.String getDocumentId() {
		return this.documentId;
	}
	public void setDocumentId(java.lang.String documentId) {
		this.documentId = documentId;
	}
	
	/**
	 * Model for Extracted
	 */
	public Documents extracted(com.example.model.Extracted extracted) {
		setExtracted(extracted);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "Model for Extracted")
	@com.fasterxml.jackson.annotation.JsonProperty("extracted")
	@javax.validation.Valid
	public com.example.model.Extracted getExtracted() {
		return this.extracted;
	}
	public void setExtracted(com.example.model.Extracted extracted) {
		this.extracted = extracted;
	}
	
	/**
	 * Model for File
	 */
	public Documents facePhoto(com.example.model.File facePhoto) {
		setFacePhoto(facePhoto);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "Model for File")
	@com.fasterxml.jackson.annotation.JsonProperty("face_photo")
	@javax.validation.Valid
	public com.example.model.File getFacePhoto() {
		return this.facePhoto;
	}
	public void setFacePhoto(com.example.model.File facePhoto) {
		this.facePhoto = facePhoto;
	}
	
	/**
	 * Model for File
	 */
	public Documents frontDocument(com.example.model.File frontDocument) {
		setFrontDocument(frontDocument);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "Model for File")
	@com.fasterxml.jackson.annotation.JsonProperty("front_document")
	@javax.validation.Valid
	public com.example.model.File getFrontDocument() {
		return this.frontDocument;
	}
	public void setFrontDocument(com.example.model.File frontDocument) {
		this.frontDocument = frontDocument;
	}
	
	/**
	 */
	public Documents identityDocumentType(java.lang.String identityDocumentType) {
		setIdentityDocumentType(identityDocumentType);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("identity_document_type")
	public java.lang.String getIdentityDocumentType() {
		return this.identityDocumentType;
	}
	public void setIdentityDocumentType(java.lang.String identityDocumentType) {
		this.identityDocumentType = identityDocumentType;
	}
	
	/**
	 */
	public Documents ocr(java.lang.Boolean ocr) {
		setOcr(ocr);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("ocr")
	public java.lang.Boolean getOcr() {
		return this.ocr;
	}
	public void setOcr(java.lang.Boolean ocr) {
		this.ocr = ocr;
	}
	
	/**
	 * Model for File
	 */
	public Documents originalFrontDocument(com.example.model.File originalFrontDocument) {
		setOriginalFrontDocument(originalFrontDocument);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "Model for File")
	@com.fasterxml.jackson.annotation.JsonProperty("original_front_document")
	@javax.validation.Valid
	public com.example.model.File getOriginalFrontDocument() {
		return this.originalFrontDocument;
	}
	public void setOriginalFrontDocument(com.example.model.File originalFrontDocument) {
		this.originalFrontDocument = originalFrontDocument;
	}
	
	/**
	 */
	public Documents updatedAt(java.time.OffsetDateTime updatedAt) {
		setUpdatedAt(updatedAt);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("updated_at")
	public java.time.OffsetDateTime getUpdatedAt() {
		return this.updatedAt;
	}
	public void setUpdatedAt(java.time.OffsetDateTime updatedAt) {
		this.updatedAt = updatedAt;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Documents documents = (Documents) o;
		return java.util.Objects.equals(this.asfBreakdown, documents.asfBreakdown)
				&& java.util.Objects.equals(this.createdAt, documents.createdAt)
				&& java.util.Objects.equals(this.documentId, documents.documentId)
				&& java.util.Objects.equals(this.extracted, documents.extracted)
				&& java.util.Objects.equals(this.facePhoto, documents.facePhoto)
				&& java.util.Objects.equals(this.frontDocument, documents.frontDocument)
				&& java.util.Objects.equals(this.identityDocumentType, documents.identityDocumentType)
				&& java.util.Objects.equals(this.ocr, documents.ocr)
				&& java.util.Objects.equals(this.originalFrontDocument, documents.originalFrontDocument)
				&& java.util.Objects.equals(this.updatedAt, documents.updatedAt);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.asfBreakdown, this.createdAt, this.documentId, this.extracted, this.facePhoto, this.frontDocument, this.identityDocumentType, this.ocr, this.originalFrontDocument, this.updatedAt);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Documents {\n");
		
		sb.append("    asfBreakdown: ").append(toIndentedString(this.asfBreakdown)).append("\n");
		sb.append("    createdAt: ").append(toIndentedString(this.createdAt)).append("\n");
		sb.append("    documentId: ").append(toIndentedString(this.documentId)).append("\n");
		sb.append("    extracted: ").append(toIndentedString(this.extracted)).append("\n");
		sb.append("    facePhoto: ").append(toIndentedString(this.facePhoto)).append("\n");
		sb.append("    frontDocument: ").append(toIndentedString(this.frontDocument)).append("\n");
		sb.append("    identityDocumentType: ").append(toIndentedString(this.identityDocumentType)).append("\n");
		sb.append("    ocr: ").append(toIndentedString(this.ocr)).append("\n");
		sb.append("    originalFrontDocument: ").append(toIndentedString(this.originalFrontDocument)).append("\n");
		sb.append("    updatedAt: ").append(toIndentedString(this.updatedAt)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/Documents.java <==
package com.example.model;

/**
 * Model for Documents
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.443Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "Documents", description = "Model for Documents")
@javax.xml.bind.annotation.XmlRootElement(name = "Documents")
public class Documents implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private com.example.model.AsfBreakdown asfBreakdown = null;
	private java.time.OffsetDateTime createdAt = null;
	private java.lang.String documentId = null;
	private com.example.model.Extracted extracted = null;
	private com.example.model.File facePhoto = null;
	private com.example.model.File frontDocument = null;
	private java.lang.String identityDocumentType = null;
	private java.lang.Boolean ocr = null;
	private com.example.model.File originalFrontDocument = null;
	private java.time.OffsetDateTime updatedAt = null;
	
	/**
	 * Model for AsfBreakdown
	 */
	public Documents asfBreakdown(com.example.model.AsfBreakdown asfBreakdown) {
		setAsfBreakdown(asfBreakdown);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "asf_breakdown", description = "Model for AsfBreakdown")
	@com.fasterxml.jackson.annotation.JsonProperty("asf_breakdown")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public com.example.model.AsfBreakdown getAsfBreakdown() {
		return this.asfBreakdown;
	}
	public void setAsfBreakdown(com.example.model.AsfBreakdown asfBreakdown) {
		this.asfBreakdown = asfBreakdown;
	}
	
	/**
	 */
	public Documents createdAt(java.time.OffsetDateTime createdAt) {
		setCreatedAt(createdAt);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "created_at")
	@com.fasterxml.jackson.annotation.JsonProperty("created_at")
	public java.time.OffsetDateTime getCreatedAt() {
		return this.createdAt;
	}
	public void setCreatedAt(java.time.OffsetDateTime createdAt) {
		this.createdAt = createdAt;
	}
	
	/**
	 */
	public Documents documentId(java.lang.String documentId) {
		setDocumentId(documentId);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "document_id")
	@com.fasterxml.jackson.annotation.JsonProperty("document_id")
	public java.lang.String getDocumentId() {
		return this.documentId;
	}
	public void setDocumentId(java.lang.String documentId) {
		this.documentId = documentId;
	}
	
	/**
	 * Model for Extracted
	 */
	public Documents extracted(com.example.model.Extracted extracted) {
		setExtracted(extracted);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "extracted", description = "Model for Extracted")
	@com.fasterxml.jackson.annotation.JsonProperty("extracted")
	@javax.validation.Valid
	public com.example.model.Extracted getExtracted() {
		return this.extracted;
	}
	public void setExtracted(com.example.model.Extracted extracted) {
		this.extracted = extracted;
	}
	
	/**
	 * Model for File
	 */
	public Documents facePhoto(com.example.model.File facePhoto) {
		setFacePhoto(facePhoto);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "face_photo", description = "Model for File")
	@com.fasterxml.jackson.annotation.JsonProperty("face_photo")
	@javax.validation.Valid
	public com.example.model.File getFacePhoto() {
		return this.facePhoto;
	}
	public void setFacePhoto(com.example.model.File facePhoto) {
		this.facePhoto = facePhoto;
	}
	
	/**
	 * Model for File
	 */
	public Documents frontDocument(com.example.model.File frontDocument) {
		setFrontDocument(frontDocument);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "front_document", description = "Model for File")
	@com.fasterxml.jackson.annotation.JsonProperty("front_document")
	@javax.validation.Valid
	public com.example.model.File getFrontDocument() {
		return this.frontDocument;
	}
	public void setFrontDocument(com.example.model.File frontDocument) {
		this.frontDocument = frontDocument;
	}
	
	/**
	 */
	public Documents identityDocumentType(java.lang.String identityDocumentType) {
		setIdentityDocumentType(identityDocumentType);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "identity_document_type")
	@com.fasterxml.jackson.annotation.JsonProperty("identity_document_type")
	public java.lang.String getIdentityDocumentType() {
		return this.identityDocumentType;
	}
	public void setIdentityDocumentType(java.lang.String identityDocumentType) {
		this.identityDocumentType = identityDocumentType;
	}
	
	/**
	 */
	public Documents ocr(java.lang.Boolean ocr) {
		setOcr(ocr);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "ocr")
	@com.fasterxml.jackson.annotation.JsonProperty("ocr")
	public java.lang.Boolean getOcr() {
		return this.ocr;
	}
	public void setOcr(java.lang.Boolean ocr) {
		this.ocr = ocr;
	}
	
	/**
	 * Model for File
	 */
	public Documents originalFrontDocument(com.example.model.File originalFrontDocument) {
		setOriginalFrontDocument(originalFrontDocument);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "original_front_document", description = "Model for File")
	@com.fasterxml.jackson.annotation.JsonProperty("original_front_document")
	@javax.validation.Valid
	public com.example.model.File getOriginalFrontDocument() {
		return this.originalFrontDocument;
	}
	public void setOriginalFrontDocument(com.example.model.File originalFrontDocument) {
		this.originalFrontDocument = originalFrontDocument;
	}
	
	/**
	 */
	public Documents updatedAt(java.time.OffsetDateTime updatedAt) {
		setUpdatedAt(updatedAt);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "updated_at")
	@com.fasterxml.jackson.annotation.JsonProperty("updated_at")
	public java.time.OffsetDateTime getUpdatedAt() {
		return this.updatedAt;
	}
	public void setUpdatedAt(java.time.OffsetDateTime updatedAt) {
		this.updatedAt = updatedAt;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Documents documents = (Documents) o;
		return java.util.Objects.equals(this.asfBreakdown, documents.asfBreakdown)
				&& java.util.Objects.equals(this.createdAt, documents.createdAt)
				&& java.util.Objects.equals(this.documentId, documents.documentId)
				&& java.util.Objects.equals(this.extracted, documents.extracted)
				&& java.util.Objects.equals(this.facePhoto, documents.facePhoto)
				&& java.util.Objects.equals(this.frontDocument, documents.frontDocument)
				&& java.util.Objects.equals(this.identityDocumentType, documents.identityDocumentType)
				&& java.util.Objects.equals(this.ocr, documents.ocr)
				&& java.util.Objects.equals(this.originalFrontDocument, documents.originalFrontDocument)
				&& java.util.Objects.equals(this.updatedAt, documents.updatedAt);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.asfBreakdown, this.createdAt, this.documentId, this.extracted, this.facePhoto, this.frontDocument, this.identityDocumentType, this.ocr, this.originalFrontDocument, this.updatedAt);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Documents {\n");
		
		sb.append("    asfBreakdown: ").append(toIndentedString(this.asfBreakdown)).append("\n");
		sb.append("    createdAt: ").append(toIndentedString(this.createdAt)).append("\n");
		sb.append("    documentId: ").append(toIndentedString(this.documentId)).append("\n");
		sb.append("    extracted: ").append(toIndentedString(this.extracted)).append("\n");
		sb.append("    facePhoto: ").append(toIndentedString(this.facePhoto)).append("\n");
		sb.append("    frontDocument: ").append(toIndentedString(this.frontDocument)).append("\n");
		sb.append("    identityDocumentType: ").append(toIndentedString(this.identityDocumentType)).append("\n");
		sb.append("    ocr: ").append(toIndentedString(this.ocr)).append("\n");
		sb.append("    originalFrontDocument: ").append(toIndentedString(this.originalFrontDocument)).append("\n");
		sb.append("    updatedAt: ").append(toIndentedString(this.updatedAt)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
